.. kuryr documentation master file, created by
   sphinx-quickstart on Tue Jul  9 22:26:36 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to kuryr-libnetwork's documentation!
========================================================

Contents:

.. toctree::
   :maxdepth: 2

   readme
   config-sriov.rst
   fullstack-test

Design and Developer Docs
==========================

.. toctree::
   :maxdepth: 1

   devref/index

Installation Guide
==================
.. toctree::
   :maxdepth: 1

   install/index

Indices and tables
==================

* :ref:`search`

